Asynchronous HTTP Client - Clojure - Utils
Asynchronous HTTP Client - Clojure - Utils
(set-proxy {:keys [protocol host port user password]} b)Sets proxy on builder. Note that in v1.0.0 you must also set a realm to enable HTTPS traffic via the proxy.
Sets proxy on builder. Note that in v1.0.0 you must also set a realm to enable HTTPS traffic via the proxy.
(set-realm {:keys [type user password realm preemptive target-proxy]
:or {type :basic}}
b)Sets realm on builder. Note that in v.1.0.0 you must set a realm to enable HTTPS traffic via the proxy.
Sets realm on builder. Note that in v.1.0.0 you must set a realm to enable HTTPS traffic via the proxy.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |